=begin
/****************************************************************************
** $Id: mdi.rb,v 1.1.1.1 2002/12/22 14:19:53 taka-hr Exp $
**
** Copyright (C) 1992-2000 Troll Tech AS.  All rights reserved.
**
** This file is part of an example program for Qt.  This example
** program may be used, distributed and modified without limitation.
**
*****************************************************************************/
=end
require "qte"
include Qte
require "qpe"
include Qpe
require "mdi_application_lib.rb"
#    QPEApplication::setStyle(QCDEStyle.new)
    a = QPEApplication.new([$0]+ARGV)
#    QApplication::setStyle(QWindowsStyle.new)
    mw = ApplicationWindow.new
    mw.setCaption( QString.new("Multiple Document") )
    a.showMainWidget(mw)
    connect( a, QSIGNAL("lastWindowClosed()"), a, QSLOT("quit()") );
    a.exec
